Documentation
¶
Overview ¶
Package doc Worker.
Documentation of Worker.
Schemes: http Version: %VERSION_TO_BE_REPLACED_BY_GITRUNNER% Host: localhost:7712 BasePath: / Consumes: - application/json Produces: - application/json
swagger:meta
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EmptyResponse ¶
type EmptyResponse struct{}
EmptyResponse are sent when the HTTP status code is 204.
swagger:response emptyResponse
type GenericError ¶
type GenericError struct {
// The error message
//
// required: true
Message string `json:"message"`
}
A GenericError is the default error message that is generated. For certain status codes there are more appropriate error structures.
swagger:response genericError
Click to show internal directories.
Click to hide internal directories.